@@ -1,8 +1,5 @@
-/* Copyright (c) 2002-2017 Pigeonhole authors, see the included COPYING file
- */
-
-#ifndef __SIEVE_PARSER_H
-#define __SIEVE_PARSER_H
+#ifndef SIEVE_PARSER_H
+#define SIEVE_PARSER_H
 
 #include "lib.h"
 
@@ -16,4 +13,4 @@ struct sieve_parser *sieve_parser_create
 void sieve_parser_free(struct sieve_parser **parser);
 bool sieve_parser_run(struct sieve_parser *parser, struct sieve_ast **ast);
 
-#endif /* __SIEVE_PARSER_H */
+#endif
